//@line 2 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/channel-prefs.js"
pref("app.update.channel", "nightly");
